#!/usr/bin/env perl

use strict;
use warnings;

use Test::More;
use Test::Exception;

use Person;

use DateTime;

subtest 'Calculate Age - On Birthday' => sub {
    my $expected_age = 21;

    my $person = Person->new(
        first_name => 'Bob',
        last_name  => 'Smith',
        birth_datetime => DateTime->now->subtract( years => $expected_age ),
    );

    my $calculated_age;
    lives_ok {
        $calculated_age = $person->age();
    } 'Lives through calculation of age';

    note( "Calculated Age: $calculated_age" );
    cmp_ok( $calculated_age, '==', $expected_age, 'Correct age' );
};

subtest 'Calculate Age - Not On Birthday' => sub {
    my $expected_age = 21;

    my $person = Person->new(
        first_name => 'Bob',
        last_name  => 'Smith',
        birth_datetime => DateTime->now->subtract( years => $expected_age, days => 30 ),
    );

    my $calculated_age;
    lives_ok {
        $calculated_age = $person->age();
    } 'Lives through calculation of age';

    note( "Calculated Age: $calculated_age" );
    cmp_ok( $calculated_age, '==', $expected_age, 'Correct age' );
};

done_testing;
