#!/usr/bin/env perl

use strict;
use warnings;

use Test::More;
use Test::Exception;

use Moose;

use Role::Exercise;

use Readonly;
Readonly my $TEST_CLASS => Moose::Meta::Class->create(
    'Test::More',
    roles   => [ 'Role::Exercise' ],
    methods => {
        age => sub { return 21 },
        subtest => sub { ... },
    }
);

subtest 'Starts At Rest' => sub {
    my $object = $TEST_CLASS->new_object();

    ok( !$object->is_exercising, 'Correctly not exercising' );
    cmp_ok( $object->base_heart_rate, '==', $object->age * 2, 'Correct base_heart_rate' );
    cmp_ok( $object->heart_rate,      '==', $object->base_heart_rate, 'Correct heart_rate' );
};

subtest 'Workout Routine' => sub {
    my $object = $TEST_CLASS->new_object();

    subtest 'Walk' => sub {
        lives_ok {
            $object->walk();
        } 'Lives through walking';

        ok( $object->is_exercising, 'Correctly exercising' );
        cmp_ok( $object->heart_rate, '==', $object->base_heart_rate * 2, 'Correct heart_rate' );
    };

    subtest 'Rest' => sub {
        lives_ok {
            $object->rest();
        } 'Lives through resting';

        ok( !$object->is_exercising, 'Correctly not exercising' );
        cmp_ok( $object->heart_rate, '==', $object->base_heart_rate, 'Correct heart_rate' );

    };

    subtest 'Run' => sub {
        lives_ok {
            $object->run();
        } 'Lives through runnning';

        ok( $object->is_exercising, 'Correctly exercising' );
        cmp_ok( $object->heart_rate, '==', $object->base_heart_rate * 3, 'Correct heart_rate' );
    };
};

done_testing;
